( cd usr/lib ; rm -rf libpstoedit.so.0 )
( cd usr/lib ; ln -sf libpstoedit.so.0.0.0 libpstoedit.so.0 )
( cd usr/lib ; rm -rf libpstoedit.so )
( cd usr/lib ; ln -sf libpstoedit.so.0.0.0 libpstoedit.so )
( cd usr/lib/pstoedit ; rm -rf libp2edrvstd.so.0 )
( cd usr/lib/pstoedit ; ln -sf libp2edrvstd.so.0.0.0 libp2edrvstd.so.0 )
( cd usr/lib/pstoedit ; rm -rf libp2edrvstd.so )
( cd usr/lib/pstoedit ; ln -sf libp2edrvstd.so.0.0.0 libp2edrvstd.so )
( cd usr/lib/pstoedit ; rm -rf libp2edrvlplot.so.0 )
( cd usr/lib/pstoedit ; ln -sf libp2edrvlplot.so.0.0.0 libp2edrvlplot.so.0 )
( cd usr/lib/pstoedit ; rm -rf libp2edrvlplot.so )
( cd usr/lib/pstoedit ; ln -sf libp2edrvlplot.so.0.0.0 libp2edrvlplot.so )
#%% begin initialize pstoedit-3.50-i586-P1
chk=`grep pstoedit /etc/ld.so.conf`
if [ "$chk.x" = ".x" ]; then
  cat <<EOF >> /etc/ld.so.conf
/usr/lib/pstoedit
EOF
ldconfig
fi
#%% end
